# 2021-07-21 - Liquidity Bootstrapping Pool

Deployment of the `LiquidityBootstrappingPool`, for Liquidity Bootstrapping Pools of up to 4 tokens.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [`LiquidityBootstrappingPool` ABI](./abi/LiquidityBootstrappingPool.json)
